@@ -44,11 +44,6 @@ class AggregatorConfig:
     peak_sorting_method: PeakSortingMethod = attrs.field(default=PeakSortingMethod.HIGHEST_RCS)
 
 
-@attrs.frozen(kw_only=True)
-class AggregatorContext:
-    offset_m: float = attrs.field(default=0.0)
-
-
 @attrs.frozen(kw_only=True)
 class AggregatorResult:
     processor_results: list[ProcessorResult] = attrs.field()
@@ -79,11 +74,9 @@ class Aggregator:
         session_config: a121.SessionConfig,
         extended_metadata: list[dict[int, a121.Metadata]],
         config: AggregatorConfig,
-        context: AggregatorContext,
         specs: list[ProcessorSpec],
     ):
         self.config = config
-        self.context = context
         self.specs = specs
 
         self.processors: list[Processor] = []
@@ -155,7 +148,7 @@ class Aggregator:
         dists_sorted = self._sort_peaks(
             dists_merged, ampls_merged, rcs_merged, self.config.peak_sorting_method
         )
-        dists_sorted -= self.context.offset_m
+
         return AggregatorResult(
             processor_results=processors_result,
             estimated_distances=dists_sorted,
@@ -203,12 +196,17 @@ class Aggregator:
 
         peak_cluster_idxs = np.where(min_peak_to_peak_dist < np.diff(distances_sorted))[0] + 1
         distances_merged = [
-            np.mean(cluster) for cluster in np.split(distances_sorted, peak_cluster_idxs)
+            np.mean(cluster) if dists.size != 0 else np.nan
+            for cluster in np.split(distances_sorted, peak_cluster_idxs)
         ]
         amplitudes_merged = [
-            np.mean(cluster) for cluster in np.split(amplitudes_sorted, peak_cluster_idxs)
+            np.mean(cluster) if dists.size != 0 else np.nan
+            for cluster in np.split(amplitudes_sorted, peak_cluster_idxs)
+        ]
+        rcs_merged = [
+            np.mean(cluster) if dists.size != 0 else np.nan
+            for cluster in np.split(rcs_sorted, peak_cluster_idxs)
         ]
-        rcs_merged = [np.mean(cluster) for cluster in np.split(rcs_sorted, peak_cluster_idxs)]
         return (np.array(distances_merged), np.array(amplitudes_merged), np.array(rcs_merged))
 
     @staticmethod
