@@ -26,6 +26,7 @@ from acconeer.exptool.a121.algo._plugins import (
 from acconeer.exptool.app.new import (
     BUTTON_ICON_COLOR,
     AppModel,
+    BackendLogger,
     ConnectionState,
     GeneralMessage,
     HandledException,
@@ -58,9 +59,6 @@ from ._detector import (
 )
 
 
-log = logging.getLogger(__name__)
-
-
 @attrs.mutable(kw_only=True)
 class SharedState:
     sensor_id: int = attrs.field(default=1)
@@ -69,36 +67,6 @@ class SharedState:
     replaying: bool = attrs.field(default=False)
 
 
-def serialized_attrs_instance_has_diverged(attrs_instance: Any) -> bool:
-    """Checks (recursively) if a de-serialized attrs-instances contains
-    all attributes defined its respective class definition.
-
-    :param attrs_config:
-        An instance of an attrs-class, that possibly contains other attrs-instances.
-    :returns: True if any attrs-instance have diverged from its class, False otherwise
-    """
-    # TODO: Should end up in the `Config` ABC
-    attrs_class = type(attrs_instance)
-    if not attrs.has(attrs_class):
-        raise TypeError(f"Cannot check object of type {attrs_class!r}. It's not an attrs-class.")
-
-    for attribute in attrs_instance.__attrs_attrs__:
-        try:
-            value = getattr(attrs_instance, attribute.name)
-
-            if attrs.has(type(value)) and serialized_attrs_instance_has_diverged(value):
-                return True
-        except AttributeError:
-            log.info(
-                f"Serialized object of type {attrs_class.__name__!r} "
-                + "seems to have converged from its definition."
-            )
-            log.info(f"Should contain the attribute {attribute.name!r} but did not.")
-            return True
-
-    return False
-
-
 class BackendPlugin(DetectorBackendPluginBase[SharedState]):
     def __init__(
         self, callback: Callable[[Message], None], generation: PluginGeneration, key: str
@@ -111,6 +79,7 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         self._recorder: Optional[a121.H5Recorder] = None
         self._opened_record: Optional[a121.H5Record] = None
         self._detector_instance: Optional[Detector] = None
+        self._log = BackendLogger.getLogger(__name__)
 
         self.restore_defaults()
 
@@ -173,7 +142,7 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
                 context_group = f.create_group("context")
                 self.shared_state.context.to_h5(context_group)
         except Exception:
-            log.warning("Detector could not write to cache")
+            self._log.warning("Detector could not write to cache")
 
         self.detach_client()
 
@@ -311,7 +280,7 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         self.callback(GeneralMessage(name="plot", data=result, recipient="plot_plugin"))
 
     @is_task
-    def record_threshold(self) -> None:
+    def calibrate_detector(self) -> None:
         if self._started:
             raise RuntimeError
 
@@ -330,38 +299,9 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
                 detector_config=self.shared_state.config,
                 context=self.shared_state.context,
             )
-            self._detector_instance.record_threshold()
+            self._detector_instance.calibrate_detector()
         except Exception as exc:
-            raise HandledException("Failed to record threshold") from exc
-        finally:
-            self.callback(PluginStateMessage(state=PluginState.LOADED_IDLE))
-
-        self.shared_state.context = self._detector_instance.context
-        self.broadcast()
-
-    @is_task
-    def calibrate_close_range(self) -> None:
-        if self._started:
-            raise RuntimeError
-
-        if self._client is None:
-            raise RuntimeError
-
-        if not self._client.connected:
-            raise RuntimeError
-
-        self.callback(PluginStateMessage(state=PluginState.LOADED_BUSY))
-
-        try:
-            self._detector_instance = Detector(
-                client=self._client,
-                sensor_id=self.shared_state.sensor_id,
-                detector_config=self.shared_state.config,
-                context=self.shared_state.context,
-            )
-            self._detector_instance.calibrate_close_range()
-        except Exception as exc:
-            raise HandledException("Failed to calibrate close range") from exc
+            raise HandledException("Failed to calibrate detector") from exc
         finally:
             self.callback(PluginStateMessage(state=PluginState.LOADED_IDLE))
 
@@ -465,15 +405,10 @@ class ViewPlugin(DetectorViewPluginBase):
 
     TEXT_MSG_MAP = {
         DetailedStatus.OK: "Ready to start.",
-        DetailedStatus.CLOSE_RANGE_CALIBRATION_MISSING: "Run close range calibration.",
-        DetailedStatus.CLOSE_RANGE_CALIBRATION_CONFIG_MISMATCH: (
-            "Configuration does not match"
-            + " configuration used during close range calibration. Please rerun calibration."
-        ),
-        DetailedStatus.RECORDED_THRESHOLD_MISSING: "Run recorded threshold calibration.",
-        DetailedStatus.RECORDED_THRESHOLD_CONFIG_MISMATCH: (
-            "Configuration does not match configuration"
-            + " used during recorded threshold calibration. Please rerun calibration."
+        DetailedStatus.CALIBRATION_MISSING: "Run detector calibration.",
+        DetailedStatus.CONFIG_MISMATCH: (
+            "Current configuration does not match the configuration "
+            + "used during detector calibration. Run detector calibration."
         ),
         DetailedStatus.INVALID_DETECTOR_CONFIG_RANGE: (
             "Invalid detector config. Valid measurement"
@@ -488,6 +423,7 @@ class ViewPlugin(DetectorViewPluginBase):
     def __init__(self, app_model: AppModel, view_widget: QWidget) -> None:
         super().__init__(app_model=app_model, view_widget=view_widget)
         self.app_model = app_model
+        self._log = logging.getLogger(__name__)
 
         sticky_layout = QVBoxLayout()
         sticky_layout.setContentsMargins(0, 0, 0, 0)
@@ -512,19 +448,12 @@ class ViewPlugin(DetectorViewPluginBase):
         self.stop_button.setToolTip("Stops the session.\n\nShortcut: Space")
         self.stop_button.clicked.connect(self._send_stop_request)
 
-        self.record_threshold_button = QPushButton(
-            qta.icon("fa.video-camera", color=BUTTON_ICON_COLOR),
-            "Record threshold",
+        self.calibrate_detector_button = QPushButton(
+            qta.icon("fa.circle", color=BUTTON_ICON_COLOR),
+            "Calibrate detector",
             self.sticky_widget,
         )
-        self.record_threshold_button.clicked.connect(self._on_record_threshold)
-
-        self.close_range_calibration_button = QPushButton(
-            qta.icon("mdi.adjust", color=BUTTON_ICON_COLOR),
-            "Calibrate close range",
-            self.sticky_widget,
-        )
-        self.close_range_calibration_button.clicked.connect(self._on_close_range_calibration)
+        self.calibrate_detector_button.clicked.connect(self._on_calibrate_detector)
 
         self.defaults_button = QPushButton(
             qta.icon("mdi6.restore", color=BUTTON_ICON_COLOR),
@@ -539,10 +468,9 @@ class ViewPlugin(DetectorViewPluginBase):
         button_group = GridGroupBox("Controls", parent=self.sticky_widget)
         button_group.layout().addWidget(self.start_button, 0, 0)
         button_group.layout().addWidget(self.stop_button, 0, 1)
-        button_group.layout().addWidget(self.close_range_calibration_button, 1, 0)
-        button_group.layout().addWidget(self.record_threshold_button, 1, 1)
-        button_group.layout().addWidget(self.defaults_button, 2, 0, 1, -1)
-        button_group.layout().addWidget(self.message_box, 3, 0, 1, -1)
+        button_group.layout().addWidget(self.calibrate_detector_button, 1, 0, 1, -1)
+        button_group.layout().addWidget(self.defaults_button, 3, 0, 1, -1)
+        button_group.layout().addWidget(self.message_box, 4, 0, 1, -1)
 
         sticky_layout.addWidget(button_group)
 
@@ -632,7 +560,7 @@ class ViewPlugin(DetectorViewPluginBase):
             "signal_quality": pidgets.FloatSliderParameterWidgetFactory(
                 name_label_text="Signal quality",
                 decimals=1,
-                limits=(0, 25),
+                limits=(-10, 35),
                 show_limit_values=False,
                 limit_texts=("Less power", "Higher quality"),
             ),
@@ -650,8 +578,7 @@ class ViewPlugin(DetectorViewPluginBase):
 
         if state is None:
             self.start_button.setEnabled(False)
-            self.close_range_calibration_button.setEnabled(False)
-            self.record_threshold_button.setEnabled(False)
+            self.calibrate_detector_button.setEnabled(False)
             self.stop_button.setEnabled(False)
             self.defaults_button.setEnabled(False)
 
@@ -682,12 +609,7 @@ class ViewPlugin(DetectorViewPluginBase):
             and app_model.connection_state == ConnectionState.CONNECTED
         )
 
-        self.close_range_calibration_button.setEnabled(
-            ready_for_session and detector_status.ready_to_calibrate_close_range
-        )
-        self.record_threshold_button.setEnabled(
-            ready_for_session and detector_status.ready_to_record_threshold
-        )
+        self.calibrate_detector_button.setEnabled(ready_for_session)
         self.start_button.setEnabled(ready_for_session and detector_status.ready_to_start)
         self.stop_button.setEnabled(app_model.plugin_state == PluginState.LOADED_BUSY)
 
@@ -701,7 +623,7 @@ class ViewPlugin(DetectorViewPluginBase):
     # TODO: move to detector base (?)
     def handle_message(self, message: GeneralMessage) -> None:
         if message.name == "sync":
-            log.debug(f"{type(self).__name__} syncing")
+            self._log.debug(f"{type(self).__name__} syncing")
 
             self.config_editor.sync()
         else:
@@ -717,12 +639,8 @@ class ViewPlugin(DetectorViewPluginBase):
         self.app_model.put_backend_plugin_task("stop_session", on_error=self.app_model.emit_error)
         self.app_model.set_plugin_state(PluginState.LOADED_STOPPING)
 
-    def _on_record_threshold(self) -> None:
-        self.app_model.put_backend_plugin_task("record_threshold")
-        self.app_model.set_plugin_state(PluginState.LOADED_STARTING)
-
-    def _on_close_range_calibration(self) -> None:
-        self.app_model.put_backend_plugin_task("calibrate_close_range")
+    def _on_calibrate_detector(self) -> None:
+        self.app_model.put_backend_plugin_task("calibrate_detector")
         self.app_model.set_plugin_state(PluginState.LOADED_STARTING)
 
     def _send_defaults_request(self) -> None:
