@@ -34,6 +34,7 @@ from acconeer.exptool.app.new.backend import (
     ClosedTask,
     ConnectionStateMessage,
     GeneralMessage,
+    LogMessage,
     Message,
     PluginStateMessage,
     StatusMessage,
@@ -106,6 +107,8 @@ class AppModel(QObject):
     sig_message_view_plugin = Signal(object)
     sig_status_message = Signal(object)
     sig_rate_stats = Signal(float, bool, float, bool)
+    sig_backend_cpu_percent = Signal(int)
+    sig_backend_state_changed = Signal(object)
 
     plugins: list[PluginSpec]
     plugin: Optional[PluginSpec]
@@ -195,6 +198,9 @@ class AppModel(QObject):
     def broadcast(self) -> None:
         self.sig_notify.emit(self)
 
+    def broadcast_backend_state(self) -> None:
+        self.sig_backend_state_changed.emit(self.backend_plugin_state)
+
     def emit_error(self, exception: Exception, traceback_format_exc: Optional[str] = None) -> None:
         log.debug("Emitting error")
         self.sig_error.emit(exception, traceback_format_exc)
@@ -262,9 +268,20 @@ class AppModel(QObject):
         elif isinstance(message, BackendPluginStateMessage):
             log.debug("Got backend plugin state message")
             self.backend_plugin_state = message.state
+            self.broadcast_backend_state()
             self.broadcast()
         elif isinstance(message, StatusMessage):
             self.send_status_message(message.status)
+        elif isinstance(message, LogMessage):
+            module_logger = logging.getLogger(message.module_name)
+            loglevel_to_logfunc = {
+                "CRITICAL": module_logger.critical,
+                "ERROR": module_logger.error,
+                "WARNING": module_logger.warning,
+                "INFO": module_logger.info,
+                "DEBUG": module_logger.debug,
+            }
+            loglevel_to_logfunc[message.log_level](message.log_string)
         elif isinstance(message, GeneralMessage):
             if message.recipient is not None:
                 if message.recipient == "plot_plugin":
@@ -302,6 +319,8 @@ class AppModel(QObject):
                 stats.jitter,
                 stats.jitter_warning,
             )
+        elif message.name == "cpu_percent":
+            self.sig_backend_cpu_percent.emit(message.data)
         else:
             raise RuntimeError(f"Got unknown general message '{message.name}'")
 
@@ -312,6 +331,17 @@ class AppModel(QObject):
         self.saveable_file = path
         self.broadcast()
 
+    def _is_serial_device_unflashed(self, serial_port: Optional[str]) -> bool:
+        for port, tag in self.available_tagged_ports:
+            if port == serial_port and tag and "unflashed" in tag.lower():
+                return True
+        return False
+
+    def _is_usb_device_unflashed(self, usb_device: Optional[USBDevice]) -> bool:
+        if usb_device and "unflashed" in usb_device.name.lower():
+            return True
+        return False
+
     def _handle_port_update(
         self,
         tagged_ports: list[Tuple[str, Optional[str]]],
@@ -341,8 +371,14 @@ class AppModel(QObject):
 
         if recognized:
             self.set_connection_interface(ConnectionInterface.SERIAL)
-            self.send_status_message(f"Recognized serial port: {self.serial_connection_port}")
-            connect = True
+            if self._is_serial_device_unflashed(self.serial_connection_port):
+                connect = False
+                self.send_warning_message(
+                    f"Found unflashed device at serial port: {self.serial_connection_port}"
+                )
+            else:
+                connect = True
+                self.send_status_message(f"Recognized serial port: {self.serial_connection_port}")
 
         if usb_devices is not None:
             self.usb_connection_device, recognized = self._select_new_usb_device(
@@ -354,8 +390,16 @@ class AppModel(QObject):
             if recognized:
                 assert self.usb_connection_device is not None
                 self.set_connection_interface(ConnectionInterface.USB)
-                self.send_status_message(f"Recognized USB device: {self.usb_connection_device}")
-                connect = True
+                if self._is_usb_device_unflashed(self.usb_connection_device):
+                    connect = False
+                    self.send_warning_message(
+                        f"Found unflashed USB device: {self.usb_connection_device}"
+                    )
+                else:
+                    connect = True
+                    self.send_status_message(
+                        f"Recognized USB device: {self.usb_connection_device}"
+                    )
 
         if connect and self.autoconnect_enabled:
             self._autoconnect()
@@ -451,17 +495,19 @@ class AppModel(QObject):
             or (
                 self.connection_interface == ConnectionInterface.SERIAL
                 and self.serial_connection_port is not None
+                and not self._is_serial_device_unflashed(self.serial_connection_port)
             )
             or (
                 self.connection_interface == ConnectionInterface.USB
                 and self.usb_connection_device is not None
+                and not self._is_usb_device_unflashed(self.usb_connection_device)
             )
         )
 
     def _failed_autoconnect(
         self, exception: Exception, traceback_format_exc: Optional[str] = None
     ) -> None:
-        self.send_status_message('<p style="color: #FD5200;"><b>Failed to autoconnect</b></p>')
+        self.send_warning_message("Failed to autoconnect")
 
     def set_connection_interface(self, connection_interface: ConnectionInterface) -> None:
         self.connection_interface = connection_interface
@@ -525,6 +571,7 @@ class AppModel(QObject):
         self.sig_load_plugin.emit(plugin)
         self.plugin = plugin
         self.broadcast()
+        self.broadcast_backend_state()
 
     def save_to_file(self, path: Path) -> None:
         log.debug(f"{self.__class__.__name__} saving to file '{path}'")
@@ -575,3 +622,6 @@ class AppModel(QObject):
 
     def send_status_message(self, message: Optional[str]) -> None:
         self.sig_status_message.emit(message)
+
+    def send_warning_message(self, message: Optional[str]) -> None:
+        self.sig_status_message.emit(f'<p style="color: #FD5200;"><b>{message}</b></p>')
